from django.contrib import admin
from django.shortcuts import render_to_response
from django.template import RequestContext
from django.contrib.contenttypes.models import ContentType
from django.http import HttpResponseRedirect
from django import forms

from nsmon.views import *
from nsmon.models import Ipv6NS
from watcharp.models import watcharp

import IPy

from django.utils.translation import ugettext_lazy as _
from django.contrib.admin import SimpleListFilter
from config.models import group_vlan


def get_vlans(user):
        vlanlist = []
        if user.is_superuser == False:
                mygroups = user.groups.all()
                for group in mygroups:
                        gvs = group_vlan.objects.filter(gr_id=group)
                        for gv in gvs:
                                vlanlist.append(gv.vlan.vlan)
        else:
                vlanlist = Ipv6NS.objects.values_list('vlan', flat=True).annotate().order_by('vlan')
        return vlanlist

class VlansListFilter(SimpleListFilter):
        title = _('Vlans')
        parameter_name = 'vlan'

        def lookups(self, request, model_admin):
                vlanslist = get_vlans(request.user)
                mylist = []
                for k in vlanslist:
                        mylist.append((str(k), _(str(k))))
                return mylist

        def queryset(self, request, queryset):
                if self.value():
                        return queryset.filter(vlan=self.value())

class MyForm(forms.Form):
        q = forms.CharField(label="", widget=forms.widgets.Textarea(attrs={'cols':75, 'rows':1, 'title': 'Advanced search',}))


class EntryAdmin(admin.ModelAdmin):
	list_filter = [VlansListFilter,]
	list_display = ['modified_date', 'creation_date', 'Mac_src', 'mac_dst', 'vlan', 'ICMPv6NDOptSrcLLAddr_lladdr', 'IPv6_src', 'IPv6_dst', 'ICMPv6ND_NS_TGT',  'Counter']
	list_per_page = 25
	date_hierarchy = 'modified_date'

	def Mac_src(self, obj):
		return '<a href="%s%s" title="Macfind"><img src="/static/admin/img/icon_searchbox.png" align="left"> </a> \
			 <span style="font-family:monospace"><a href="%s%s">%s</a></span>' % ('../../switches/macfind?mac=',obj.mac_src,'../../nsmon/search?search_string=', obj.mac_src, obj.mac_src)
	Mac_src.allow_tags = True
	Mac_src.admin_order_field = 'mac_src'

	def ICMPv6NDOptSrcLLAddr_lladdr1(self, obj):
		return '<a href="%s%s" title="Macfind"><img src="/static/admin/img/icon_searchbox.png" align="left"> </a> \
			<span style="font-family:monospace"><a href="%s%s">%s</a></span>' % ('../../switches/macfind?mac=',obj.ICMPv6NDOptSrcLLAddr_lladdr,'../../nsmon/search?search_string=', obj.ICMPv6NDOptSrcLLAddr_lladdr, obj.ICMPv6NDOptSrcLLAddr_lladdr)
	ICMPv6NDOptSrcLLAddr_lladdr1.allow_tags = True

	def IPv6_dst(self, obj):
                bbb = ''
                if(obj.ipv6_dst):
                        bbb = IPy.IP(obj.ipv6_dst).strCompressed()
                return '<span style="font-family:monospace"><a href="%s%s">%s</a></span>' % ('../../nsmon/search?search_string=', obj.ipv6_dst, bbb)
        IPv6_dst.allow_tags = True
	IPv6_dst.admin_order_field = 'ipv6_dst'

	def IPv6_src(self, obj):
                aaa = ''
                if(obj.ipv6_src):
                        aaa = IPy.IP(obj.ipv6_src).strCompressed()
                return '<span style="font-family:monospace"><a href="%s%s">%s</a></span>' % ('../../nsmon/search?search_string=', obj.ipv6_src, aaa)
        IPv6_src.allow_tags = True
	IPv6_src.admin_order_field = 'ipv6_src'

        def ICMPv6ND_NS_TGT(self, obj):
                ccc = ''
                if(obj.ICMPv6ND_NS_tgt):
                        ccc = IPy.IP(obj.ICMPv6ND_NS_tgt).strCompressed()
                return '<span style="font-family:monospace"><a href="%s%s">%s</a></span>' % ('../../nsmon/search?search_string=', obj.ICMPv6ND_NS_tgt, ccc)
        ICMPv6ND_NS_TGT.allow_tags = True
	ICMPv6ND_NS_TGT.admin_order_field = 'ICMPv6ND_NS_tgt'

	def __init__(self, *args, **kwargs):
                super(EntryAdmin, self).__init__(*args, **kwargs)
		self.list_display_links = (None, )

        def get_actions(self, request):
                actions = super(EntryAdmin, self).get_actions(request)
                if request.user.is_superuser == False:
                        if 'delete_selected' in actions:
                                del actions['delete_selected']
                return actions

	def has_add_permission(self, request):
	        return False

#-----------------OLD SEARCH--------------------------
#	search_fields = ['vlan', 'mac_src', 'ICMPv6NDOptSrcLLAddr_lladdr', 'ipv6_src', 'ipv6_dst', 'ICMPv6ND_NS_tgt']

#        def queryset(self, request):
#                if request.user.is_superuser == False:
#                        vlanlist = get_vlans(request.user)
#                        return Ipv6NS.objects.filter(vlan__in=vlanlist)
#                return Ipv6NS.objects.all()

#------------------ADVANCED SEARCH---------------------
        f = MyForm()
        my_clean_data = ""
        my_error = ""
        adv_search = [('modified_date', 'Last seen'), ('creation_date','Creation date'), ('mac_src','Mac src'), ('mac_dst','Mac dst'),('vlan','Vlan'), ('ICMPv6NDOptSrcLLAddr_lladdr','Lladdr'), ('ipv6_src','IPv6 src'), ('ipv6_dst','IPv6 dst'), ('ICMPv6ND_NS_tgt','ICMPv6nd NS tgt'), ('Counter', 'Counter')]
        def get_advanced_search(self):
                return self.adv_search

        def get_my_data():
                return self.my_clean_data

        def get_my_form(self):
                ff = MyForm(initial={'q':self.my_clean_data})
                return ff

        def get_error(self):
                return self.my_error

        def check_search_string(self, p):
                stopwords = ["INSERT", "DELETE", "TRUNCATE", "SELECT", "DROP", ";"]
                for word in stopwords:
                        if word.lower() in p.lower():
                                return False
                return True

        def set_adv_params(self, request):
                if 'q' in request.GET:
                        f = MyForm(request.GET)
                        if f.is_valid():
                                if self.check_search_string(f.cleaned_data["q"]):
                                        self.my_clean_data = f.cleaned_data["q"]
                                        self.my_error = f.cleaned_data["q"]
                                else:
                                        self.my_clean_data = ""
                                        self.my_error = "Malformed filter"
                        else:
                                self.my_clean_data = ""
                                self.my_error = ""
                else:
                        self.my_clean_data = ""
                        self.my_error = ""

        def queryset(self, request):
                self.my_clean_data = ""
                if request.method == "GET":
                        self.set_adv_params(request)

                myresults = None
                if self.my_clean_data != "":
                        try:
                                self.my_error = ""
                                myresults = Ipv6NS.objects.extra(where=[self.my_clean_data])
                        except:
                                self.my_error = "Database error, the search string contains an error"
                                myresults = Ipv6NS.objects.all()
                else:
                        myresults = Ipv6NS.objects.all()

                if request.user.is_superuser == False:
                        vlanlist = get_vlans(request.user)
                        return myresults.filter(vlan__in=vlanlist)
                return myresults
        #------------------ADVANCED SEARCH---------------------


admin.site.register(Ipv6NS, EntryAdmin)
