from django.contrib import admin
from django.contrib import auth
from django.shortcuts import render_to_response
from django.template import RequestContext
from django.contrib.auth import authenticate, login
from django.contrib.admin.views.decorators import staff_member_required
from django.contrib.auth.decorators import login_required
from django import forms
from django.core.paginator import Paginator, InvalidPage, EmptyPage
from django.db.models import Avg, Max, Min, Count
from django.http import HttpResponse


from django.forms.widgets import DateInput

from nsmon.models import Ipv6NS
from watcharp.models import watcharp
from radiusacc.models import radacct

from datetime import datetime, date, timedelta

import IPy


class SearchForm(forms.Form):
	search_string = forms.CharField(label="Insert a value", max_length=64,required=True, help_text='64 characters max.')
	from_date = forms.DateField(label='Starting Date', required=False, help_text='') 
	end_date = forms.DateField(label='Ending Date', required=False, help_text='(Note: ending date must be greather than starting date)') 

def compress(ipv6):
	try:
		return IPy.IP(ipv6).strCompressed()
	except:
		return ipv6

@staff_member_required
def search_page(request):
        if request.method == "GET":
		searchstring = ''
		fromdate= ''
		try:
			searchstring = request.GET['search_string']
		except:
			searchstring = ''
		try:
			fromdate = request.GET['from_date']
			fd = datetime.strptime(fromdate,'%Y-%m-%d')
		except:
			fromdate = (date.today()-timedelta(days=7))
			fd = fromdate 
		try:
			enddate = request.GET['end_date']
			ed = datetime.strptime(enddate,'%Y-%m-%d')
		except:
			enddate = (date.today())
			ed = enddate


               	ff = SearchForm(initial={'search_string': searchstring, 'from_date':fromdate, 'end_date':enddate})
               	f = SearchForm(request.GET)
                if not f.is_valid():
                        return render_to_response("nsmon/search_result.html", {"form":ff})
                else:
			if fd > ed:
                        	return render_to_response("nsmon/search_result.html", {"form":ff})
			
		
			
			enddate = str(enddate) + ' 23:59:59'
	
			# NS
			try:
				latest_poll_list = Ipv6NS.objects.filter(mac_src = searchstring).filter(modified_date__gte=fromdate).filter(modified_date__lte=enddate) | \
							Ipv6NS.objects.filter(ipv6_src = IPy.IP(searchstring).strFullsize()).filter(modified_date__gte=fromdate).filter(modified_date__lte=enddate) | \
							Ipv6NS.objects.filter(ICMPv6ND_NS_tgt = IPy.IP(searchstring).strFullsize()).filter(modified_date__gte=fromdate).filter(modified_date__lte=enddate) 
			except:
                        	latest_poll_list = Ipv6NS.objects.filter(mac_src = searchstring).filter(modified_date__gte=fromdate).filter(modified_date__lte=enddate) | \
							Ipv6NS.objects.filter(ipv6_src__icontains = searchstring).filter(modified_date__gte=fromdate).filter(modified_date__lte=enddate) | \
							Ipv6NS.objects.filter(ICMPv6ND_NS_tgt__icontains = searchstring).filter(modified_date__gte=fromdate).filter(modified_date__lte=enddate)
			# WATCHARP
                        latest_poll_list2 = watcharp.objects.filter(mac_src = searchstring).filter(modified_date__gte=fromdate).filter(modified_date__lte=enddate) | \
						watcharp.objects.filter(psrc__icontains = searchstring).filter(modified_date__gte=fromdate).filter(modified_date__lte=enddate) | \
						watcharp.objects.filter(hostname = searchstring).filter(modified_date__gte=fromdate).filter(modified_date__lte=enddate)


			# RFC 3580	
			# For IEEE 802.1X Authenticators, this attribute is used to store the
			# Supplicant MAC address in ASCII format (upper case only), with octet
			# values separated by a "-".  Example: "00-10-A4-23-19-C0".
	
			mymac = searchstring
			try:
				mymac = searchstring.replace(":","-")
			except:
				pass

			# RADIUSACC
			latest_poll_list3 = radacct.objects.filter(AcctSessionId__icontains = searchstring).filter(AcctStartTime__gte=fromdate).filter(AcctStartTime__lte=enddate) | \
                                                radacct.objects.filter(UserName__icontains = searchstring).filter(AcctStartTime__gte=fromdate).filter(AcctStartTime__lte=enddate) | \
                                                radacct.objects.filter(CallingStationId = searchstring).filter(AcctStartTime__gte=fromdate).filter(AcctStartTime__lte=enddate) | \
                                                radacct.objects.filter(CallingStationId = mymac).filter(AcctStartTime__gte=fromdate).filter(AcctStartTime__lte=enddate) | \
                                                radacct.objects.filter(FramedIPAddress = searchstring).filter(AcctStartTime__gte=fromdate).filter(AcctStartTime__lte=enddate)

			mylist = []
			# NS 
			for poll in latest_poll_list:
				mydict = {"LastSeen":poll.modified_date, "CreationDate":poll.creation_date, \
						"MACSource":poll.mac_src, "VLAN": poll.vlan, \
						"IPSource":compress(poll.ipv6_src), \
						"IPv6Dest":compress(poll.ipv6_dst), \
						"ICMPv6NDNStarget":compress(poll.ICMPv6ND_NS_tgt), \
						"Counter":poll.Counter, \
						"Username":"", "Hostname":poll.hostname, \
						"NASIPAddress":"", "NASPortId":"" }
				mylist.append(mydict)

			# WatchArp
			for poll in latest_poll_list2:
				mydict = {"LastSeen":poll.modified_date, "CreationDate":poll.creation_date, "MACSource":poll.mac_src, "VLAN": poll.vlan, \
						"IPSource":poll.psrc, "IPv6Dest":"", "ICMPv6NDNStarget":"", "Counter":poll.counter, \
						"Username":"", "Hostname":poll.hostname, "NASIPAddress":"", "NASPortId":"" }
				mylist.append(mydict)
			
			# RADIUSACC
			for poll in latest_poll_list3:
				CallingStationId = poll.CallingStationId.replace("-",":")
				if poll.AcctStopTime is None:
					poll.AcctStopTime = poll.AcctStartTime 
                                mydict = {"LastSeen":poll.AcctStopTime, "CreationDate":poll.AcctStartTime, "MACSource":CallingStationId, "VLAN": "", \
                                                "IPSource":poll.FramedIPAddress, "IPv6Dest":"", "ICMPv6NDNStarget":"", "Counter":"", \
                                                "Username":poll.UserName, "Hostname":"", "NASIPAddress":poll.NASIPAddress, "NASPortId":poll.NASPortId }
				mylist.append(mydict)
			

                        context = { 'latest_poll_list': mylist, 'form':ff}
			# risultati non paginati
                        return render_to_response ( 'nsmon/search_result.html', context, context_instance = RequestContext(request, {}),)

	f = SearchForm()

	return render_to_response("nsmon/search_result.html", {"form":f}, RequestContext(request, {}),)




@staff_member_required
def topTalkers(request):
        latest_poll_list = Ipv6NS.objects.values('mac_src').annotate(tot=Count('mac_src')).filter(tot__gt=2).order_by('-tot')[:30]
        latest_poll_list1 = Ipv6NS.objects.values('mac_src').filter(modified_date__year=date.today().year).filter(modified_date__month=date.today().month).filter(modified_date__day=date.today().day).annotate(tot=Count('mac_src')).filter(tot__gt=2).order_by('-tot')[:30]
        latest_poll_list2 = watcharp.objects.values('mac_src').filter(modified_date__year=date.today().year).filter(modified_date__month=date.today().month).filter(modified_date__day=date.today().day).annotate(tot=Count('mac_src')).filter(tot__gt=2).order_by('-tot')[:30]
        latest_poll_list3 = watcharp.objects.values('mac_src').annotate(tot=Count('mac_src')).filter(tot__gt=2).order_by('-tot')[:30]
        context = {
                'latest_poll_list': latest_poll_list,
                'latest_poll_list1': latest_poll_list1,
                'latest_poll_list2': latest_poll_list2,
                'latest_poll_list3': latest_poll_list3,
        }
#        paginator = Paginator(context, 20)
        return render_to_response ('nsmon/toptalkers.html', context, context_instance = RequestContext(request, {}),)



