from django.contrib import admin
from ramon.models import Ipv6RA

from django.utils.translation import ugettext_lazy as _
from django.contrib.admin import SimpleListFilter
from config.models import group_vlan

from django import forms
import IPy


def get_vlans(user):
        vlanlist = []
        if user.is_superuser == False:
                mygroups = user.groups.all()
                for group in mygroups:
                        gvs = group_vlan.objects.filter(gr_id=group)
                        for gv in gvs:
                                vlanlist.append(gv.vlan.vlan)
        else:
                vlanlist = Ipv6RA.objects.values_list('vlan', flat=True).annotate().order_by('vlan')
        return vlanlist

class VlansListFilter(SimpleListFilter):
        title = _('Vlans')
        parameter_name = 'vlan'

        def lookups(self, request, model_admin):
                vlanslist = get_vlans(request.user)
                mylist = []
                for k in vlanslist:
                        mylist.append((str(k), _(str(k))))
                return mylist

        def queryset(self, request, queryset):
                if self.value():
                        return queryset.filter(vlan=self.value())


class MyForm(forms.Form):
        q = forms.CharField(label="", widget=forms.widgets.Textarea(attrs={'cols':75, 'rows':1, 'title': 'Advanced search',}))


class EntryAdmin(admin.ModelAdmin):
	list_filter = ['status', VlansListFilter]
	list_display = ['modified_date', 'creation_date', 'Mac_src', 'mac_dst', 'vlan', 'ICMPv6NDOptSrcLLAddr_LLADDR', 'IPv6_src', 'IPv6_dst', 'ICMPv6ND_RA_routerlifetime', 'ICMPv6ND_RA_M', 'ICMPv6ND_RA_O','ICMPv6ND_RA_H', 'ICMPv6ND_RA_prf', 'ICMPv6ND_RA_P', 'Prefix', 'ICMPv6NDOptPrefixInfo_L', 'ICMPv6NDOptPrefixInfo_A', 'ICMPv6NDOptPrefixInfo_prefixlen', 'ICMPv6NDOptPrefixInfo_validlifetime', 'ICMPv6NDOptPrefixInfo_preferredlifetime', 'counter', 'status'] 
	list_editable = ['status']
	list_per_page = 25
	date_hierarchy = 'modified_date'
	save_as = True

	def Mac_src(self, obj):
                return '<a href="%s%s" title="Macfind"><img src="/static/admin/img/icon_searchbox.png" align="left"> </a> \
			<span style="font-family:monospace"><a href="%s%s">%s</a></span>' % ('../../switches/macfind?mac=',obj.mac_src,'../../nsmon/search?search_string=', obj.mac_src, obj.mac_src)
        Mac_src.allow_tags = True
        Mac_src.admin_order_field = 'mac_src'

        def ICMPv6NDOptSrcLLAddr_LLADDR(self, obj):
                return '<a href="%s%s" title="Macfind"><img src="/static/admin/img/icon_searchbox.png" align="left"> </a> \
			<span style="font-family:monospace"><a href="%s%s">%s</a></span>' % ('../../switches/macfind?mac=',obj.ICMPv6NDOptSrcLLAddr_lladdr,'../../nsmon/search?search_string=', obj.ICMPv6NDOptSrcLLAddr_lladdr, obj.ICMPv6NDOptSrcLLAddr_lladdr)
        ICMPv6NDOptSrcLLAddr_LLADDR.allow_tags = True
        ICMPv6NDOptSrcLLAddr_LLADDR.admin_order_field = 'ICMPv6NDOptSrcLLAddr_lladdr'

	def IPv6_dst(self, obj):
                bbb = ''
                if(obj.ipv6_dst):
                        bbb = IPy.IP(obj.ipv6_dst).strCompressed()
                return  bbb
        IPv6_dst.allow_tags = True
        IPv6_dst.admin_order_field = 'ipv6_dst'

        def IPv6_src(self, obj):
                aaa = ''
                if(obj.ipv6_src):
                        aaa = IPy.IP(obj.ipv6_src).strCompressed()
                return aaa
        IPv6_src.allow_tags = True
        IPv6_src.admin_order_field = 'ipv6_src'

        def Prefix(self, obj):
                ccc = ''
                if(obj.ICMPv6NDOptPrefixInfo_prefix):
                        ccc = IPy.IP(obj.ICMPv6NDOptPrefixInfo_prefix).strCompressed()
                return ccc
        Prefix.allow_tags = True
        Prefix.admin_order_field = 'ICMPv6NDOptPrefixInfo_prefix'

	def __init__(self, *args, **kwargs):
                super(EntryAdmin, self).__init__(*args, **kwargs)
                self.list_display_links = (None, )

        def get_actions(self, request):
                actions = super(EntryAdmin, self).get_actions(request)
                if request.user.is_superuser == False:
                        if 'delete_selected' in actions:
                                del actions['delete_selected']
                return actions

	def has_add_permission(self, request):
	        return False

#	search_fields = ['mac_src', 'mac_dst', 'ICMPv6NDOptSrcLLAddr_lladdr', 'ipv6_src', 'ipv6_dst', 'vlan', 'ICMPv6NDOptPrefixInfo_prefix', 'ICMPv6NDOptPrefixInfo_prefixlen', 'ICMPv6NDOptPrefixInfo_validlifetime', 'ICMPv6NDOptPrefixInfo_preferredlifetime', 'ICMPv6ND_RA_routerlifetime']
#        def queryset(self, request):
#                if request.user.is_superuser == False:
#                        vlanlist = get_vlans(request.user)
#                        return Ipv6RA.objects.filter(vlan__in=vlanlist)
#                return Ipv6RA.objects.all()

#------------------ADVANCED SEARCH---------------------

        f = MyForm()
        my_clean_data = ""
        my_error = ""
        adv_search = [('modified_date', 'Last seen'), ('creation_date','Creation date'), ('mac_src','Mac src'), ('mac_dst','Mac dst'), ('vlan','Vlan'), ('ICMPv6NDOptSrcLLAddr_lladdr','ICMPv6NDOptSrcLLAddr lladdr'), ('ipv6_src','IPv6 src'), ('ipv6_dst','IPv6 dst'), ('ICMPv6ND_RA_routerlifetime','RouterLT'), ('ICMPv6ND_RA_M','M'), ('ICMPv6ND_RA_O','O'), ('ICMPv6ND_RA_H','H'), ('ICMPv6ND_RA_prf','Prf'),('ICMPv6ND_RA_P','P'),('ICMPv6NDOptPrefixInfo_prefix','Prefix'),('ICMPv6NDOptPrefixInfo_L','L'),('ICMPv6NDOptPrefixInfo_A','A'),('ICMPv6NDOptPrefixInfo_prefixlen','PrefLN'),('ICMPv6NDOptPrefixInfo_validlifetime','ValidLT'),('ICMPv6NDOptPrefixInfo_preferredlifetime','PrefferredLT'),('counter','Counter'),('status','Status')]
        def get_advanced_search(self):
                return self.adv_search

        def get_my_data():
                return self.my_clean_data

        def get_my_form(self):
                ff = MyForm(initial={'q':self.my_clean_data})
                return ff

        def get_error(self):
                return self.my_error

        def check_search_string(self, p):
                stopwords = ["INSERT", "DELETE", "TRUNCATE", "SELECT", "DROP", ";"]
                for word in stopwords:
                        if word.lower() in p.lower():
                                return False
                return True

        def set_adv_params(self, request):
                if 'q' in request.GET:
                        f = MyForm(request.GET)
                        if f.is_valid():
                                if self.check_search_string(f.cleaned_data["q"]):
                                        self.my_clean_data = f.cleaned_data["q"]
                                        self.my_error = f.cleaned_data["q"]
                                else:
                                        self.my_clean_data = ""
                                        self.my_error = "Malformed filter"
                        else:
                                self.my_clean_data = ""
                                self.my_error = ""
                else:
                        self.my_clean_data = ""
                        self.my_error = ""

        def queryset(self, request):
                self.my_clean_data = ""
                if request.method == "GET":
                        self.set_adv_params(request)

                myresults = None
                if self.my_clean_data != "":
                        try:
                                self.my_error = ""
                                myresults = Ipv6RA.objects.extra(where=[self.my_clean_data])
                        except:
                                self.my_error = "Database error, the search string contains an error"
                                myresults = Ipv6RA.objects.all()
                else:
                        myresults = Ipv6RA.objects.all()

                if request.user.is_superuser == False:
                        vlanlist = get_vlans(request.user)
                        return myresults.filter(vlan__in=vlanlist)
                return myresults
        #------------------ADVANCED SEARCH---------------------

admin.site.register(Ipv6RA, EntryAdmin)
