from django.db import models
from datetime import datetime, timedelta
from django.contrib.auth.models import User
from django.db.models.query import QuerySet

class EventQuerySet(QuerySet):
	def today(self):
		return self.filter(creation_date__range=today())

class EventManager(models.Manager):
	def get_query_set(self):
		return EventQuerySet(self.model)

# Create your models here.
class Ipv6RA(models.Model):
	ROUTER_TYPE = (
		(u'L', u'Legal'),
		(u'I', u'Illegal'),
	)
	creation_date = models.DateTimeField(auto_now=False, auto_now_add=True)
	modified_date = models.DateTimeField(auto_now=False, auto_now_add=True, verbose_name="LastSeen")
	mac_src = models.CharField(max_length=50)
	mac_dst = models.CharField(max_length=50)
	vlan = models.IntegerField(blank=True, null=True)
	ipv6_src = models.CharField(max_length=50)
	ipv6_dst = models.CharField(max_length=50)
	ICMPv6ND_RA_type = models.CharField(max_length=50)
	ICMPv6ND_RA_code = models.IntegerField(blank=True, null=True)
	ICMPv6ND_RA_cksum = models.CharField(max_length=50)
	ICMPv6ND_RA_chlim = models.IntegerField(blank=True, null=True)
	ICMPv6ND_RA_M = models.CharField(max_length=50, verbose_name="M")
	ICMPv6ND_RA_O = models.CharField(max_length=50, verbose_name="O")
	ICMPv6ND_RA_H = models.CharField(max_length=50, verbose_name="H")
	ICMPv6ND_RA_prf = models.CharField(max_length=50, verbose_name="Prf")
	ICMPv6ND_RA_P = models.CharField(max_length=50, verbose_name="P")
	ICMPv6ND_RA_res = models.CharField(max_length=50)
	ICMPv6ND_RA_routerlifetime = models.IntegerField(blank=True, null=True, verbose_name="routerLT")
	ICMPv6ND_RA_reachabletime = models.IntegerField(blank=True, null=True, verbose_name="reachabletime")
	ICMPv6ND_RA_retranstimer = models.IntegerField(blank=True, null=True)
	ICMPv6NDOptSrcLLAddr_type = models.IntegerField(blank=True, null=True)
	ICMPv6NDOptSrcLLAddr_len = models.IntegerField(blank=True, null=True)
	ICMPv6NDOptSrcLLAddr_lladdr = models.CharField(max_length=50, verbose_name="lladdr")
	ICMPv6NDOptPrefixInfo_type = models.IntegerField(blank=True, null=True)
	ICMPv6NDOptPrefixInfo_len = models.IntegerField(blank=True, null=True)
	ICMPv6NDOptPrefixInfo_prefixlen = models.IntegerField(blank=True, null=True, verbose_name="prefLN")
	ICMPv6NDOptPrefixInfo_L = models.CharField(max_length=50, verbose_name="L")
	ICMPv6NDOptPrefixInfo_A = models.CharField(max_length=50, verbose_name="A")
	ICMPv6NDOptPrefixInfo_R = models.CharField(max_length=50, verbose_name="R")
	ICMPv6NDOptPrefixInfo_res1 = models.CharField(max_length=50)
	ICMPv6NDOptPrefixInfo_validlifetime = models.CharField(max_length=50, verbose_name="validLT")
	ICMPv6NDOptPrefixInfo_preferredlifetime = models.CharField(max_length=50, verbose_name="preferredLT")
	ICMPv6NDOptPrefixInfo_res2 = models.CharField(max_length=50)
	ICMPv6NDOptPrefixInfo_prefix = models.CharField(max_length=50, verbose_name="prefix")
	counter = models.IntegerField(blank=True, null=True)
	status = models.CharField(max_length=1, choices=ROUTER_TYPE, blank=True, verbose_name="Status")
	description = models.TextField(blank=True, null=True)


	def __unicode__(self):
		return self.mac_src

	class Meta(object):
		verbose_name_plural = "IPv6 Router Advertisements detection"
                ordering = ('-modified_date', '-creation_date')


	class Admin:
        	pass

