from django.contrib import admin
from watcharp.models import watcharp
from watcharp.models import ArpConfiguration

from django.utils.translation import ugettext_lazy as _
from django.contrib.admin import SimpleListFilter
from config.models import group_vlan
from django import forms
from django.contrib import messages

def get_vlans(user):
	vlanlist = []
        if user.is_superuser == False:
		mygroups = user.groups.all()
		for group in mygroups:
			gvs = group_vlan.objects.filter(gr_id=group)
			for gv in gvs:
				vlanlist.append(gv.vlan.vlan)
	else:
		vlanlist = watcharp.objects.values_list('vlan', flat=True).annotate().order_by('vlan')	
	return vlanlist	
		
class VlansListFilter(SimpleListFilter):
	title = _('Vlans')
    	parameter_name = 'vlan'

	def lookups(self, request, model_admin):
		vlanslist = get_vlans(request.user)
		mylist = []
		for k in vlanslist:
			mylist.append((str(k), _(str(k))))
		return mylist

	def queryset(self, request, queryset):
		if self.value(): 
			return queryset.filter(vlan=self.value())


class MyForm(forms.Form):
       	q = forms.CharField(label="", widget=forms.widgets.Textarea(attrs={'cols':75, 'rows':1, 'title': 'Advanced search',}))

class EntryAdmin(admin.ModelAdmin):
	list_filter = (VlansListFilter,) 
	list_display = ['modified_date', 'creation_date', 'Mac_src', 'vlan', 'Hw_src', 'IP_src' ,'hostname', 'op', 'counter']
	date_hierarchy = 'modified_date'
	list_per_page = 25

        def Mac_src(self, obj):
		return '<a href="%s%s" title="Macfind"><img src="/static/admin/img/icon_searchbox.png" align="left"> </a> \
			<span style="font-family:monospace"><a href="%s%s">%s</a></span>' % ('../../switches/macfind?mac=',obj.mac_src,'../../nsmon/search?search_string=', obj.mac_src, obj.mac_src)
        Mac_src.allow_tags = True
        Mac_src.admin_order_field = 'mac_src'

        def Hw_src(self, obj):
		return '<a href="%s%s" title="Macfind"><img src="/static/admin/img/icon_searchbox.png" align="left"> </a> \
			 <span style="font-family:monospace"><a href="%s%s">%s</a></span>' % ('../../switches/macfind?mac=',obj.hwsrc,'../../nsmon/search?search_string=', obj.hwsrc, obj.hwsrc)
        Hw_src.allow_tags = True
        Hw_src.admin_order_field = 'hwsrc'

        def IP_src(self, obj):
                return '<span style="font-family:monospace"><a href="%s%s">%s</a></span>' % ('../../nsmon/search?search_string=', obj.psrc, obj.psrc)
        IP_src.allow_tags = True
	IP_src.admin_order_field = 'psrc'

	def __init__(self, *args, **kwargs):
        	super(EntryAdmin, self).__init__(*args, **kwargs)
	        self.list_display_links = (None, )
		
	def has_add_permission(self, request):
	        return False

	def get_actions(self, request):
		actions = super(EntryAdmin, self).get_actions(request)
		if request.user.is_superuser == False:
			if 'delete_selected' in actions:
				del actions['delete_selected']
		return actions


	#------------------ADVANCED SEARCH---------------------
	f = MyForm()	
	my_clean_data = ""
	my_error = ""
	adv_search = [('modified_date', 'Last seen'), ('creation_date','Creation date'), ('mac_src','Mac src'), ('vlan','Vlan'), ('hwsrc','Hw src'), ('psrc','Ip src'), ('hostname','Hostname'), ('op','Op'), ('counter','Counter')]
	def get_advanced_search(self):
		return self.adv_search

	def get_my_data():
		return self.my_clean_data 
	
	def get_my_form(self):
		ff = MyForm(initial={'q':self.my_clean_data})
		return ff

	def get_error(self):
		return self.my_error 

	def check_search_string(self, p):
		stopwords = ["INSERT", "DELETE", "TRUNCATE", "SELECT", "DROP", ";"]
		for word in stopwords:
			if word.lower() in p.lower():
				return False
		return True

	def set_adv_params(self, request):
		if 'q' in request.GET:
			f = MyForm(request.GET)
			if f.is_valid():
				if self.check_search_string(f.cleaned_data["q"]):
					self.my_clean_data = f.cleaned_data["q"]
					self.my_error = f.cleaned_data["q"]
				else:
					self.my_clean_data = ""
					self.my_error = "Malformed filter"
			else:
				self.my_clean_data = ""
				self.my_error = ""
		else:
			self.my_clean_data = ""
			self.my_error = ""

	def queryset(self, request):
		self.my_clean_data = "" 
		if request.method == "GET":
			self.set_adv_params(request)

		myresults = None
		if self.my_clean_data != "":
			try:
				self.my_error = ""
				myresults = watcharp.objects.extra(where=[self.my_clean_data])
			except:
				self.my_error = "Database error, the search string contains an error"
				myresults = watcharp.objects.all()
		else:
			myresults = watcharp.objects.all()
		
		if request.user.is_superuser == False:
			vlanlist = get_vlans(request.user)
			return myresults.filter(vlan__in=vlanlist)
		return myresults

	#------------------ADVANCED SEARCH---------------------

admin.site.register(watcharp, EntryAdmin)

class EntryArpConfAdmin(admin.ModelAdmin):
	list_display = ('creation_date', 'mac', 'ip', 'vlan', 'description')
	list_editable = ('mac', 'ip', 'vlan', 'description')
	search_fields = ['creation_date', 'mac', 'ip', 'vlan', 'description']
	list_per_page = 25

    	def save_model(self, request, obj, form, change):
        	messages.error(request, "Changes will have effect after NDP daemon restart (service ndp restart)")
        	super(EntryArpConfAdmin, self).save_model(request, obj, form, change)

		
	

admin.site.register(ArpConfiguration, EntryArpConfAdmin)

